package pid;

import org.bukkit.plugin.java.JavaPlugin;

import java.io.*;
import java.nio.charset.StandardCharsets;
import java.util.logging.Level;

public class Main extends JavaPlugin {
    @Override
    public void onEnable() {
        getConfig().addDefault("PIDFile", "~/bukkit.pid");
        saveConfig();
        String pid = getPid();
        savePid(pid);
    }

    @Override
    public void onDisable() {
        removePid();
    }

    private String getPid() {
        long pid = ProcessHandle.current().pid();
        return Long.toString(pid);
    }

    private void savePid(String pid) {
        String pidLocation = getPidFileLocation();
        try {
            PrintWriter writer = new PrintWriter(pidLocation, StandardCharsets.UTF_8);
            writer.print(pid);
            writer.close();
            getLogger().log(Level.INFO, "PID: " + pid);
            getLogger().log(Level.INFO, "PIDFile saved in " + pidLocation);
        } catch (IOException e) {
            getLogger().log(Level.WARNING, "Failed to write to PID file: " + e.toString());
        }
    }

    private void removePid() {
        String pidLocation = getPidFileLocation();
        File file = new File(pidLocation);
        file.deleteOnExit();
    }

    private String getPidFileLocation() {
        return (String) getConfig().get("PIDFile");
    }
}
